@@ -121,8 +121,8 @@ def on_message(client, obj, msg):
     global callback_dit
     topic = msg.topic
     try:
-        # threading.Thread(target=callback, args=(topic, msg, client), daemon=True).start()
-        callback(topic, msg, client)
+        threading.Thread(target=callback, args=(topic, msg, client), daemon=True).start()
+        # callback(topic, msg, client)
     except Exception as ex:
         print(ex)
         keys = callback_dit.keys()
@@ -138,8 +138,8 @@ def on_message(client, obj, msg):
                         isThisTopic = False
                         break
             if isThisTopic:
-                # threading.Thread(target=callback, args=(item, msg, client), daemon=True).start()
-                callback(item, msg, topic)
+                threading.Thread(target=callback, args=(item, msg, client), daemon=True).start()
+                # callback(item, msg, topic)
                 break
 
 
